==> schedulely-0.0.21.tgz: package/README.md <==
# Schedulely

### Prerelease

_This component is still very early in development. Everything is currently still subject to massive change, so use at your own risk!_

![Large Calendar Preview](/assets/large_preview.png)

---

![npm](https://img.shields.io/npm/v/schedulely) ![npm bundle size](https://img.shields.io/bundlephobia/minzip/schedulely) [![install size](https://packagephobia.com/badge?p=schedulely)](https://packagephobia.com/result?p=schedulely) ![NPM](https://img.shields.io/npm/l/schedulely?color=blue)

## 📃 Description

A react-based, light-weight, highly customizable Month calendar for React-based applications.

- Extremely small package size
- Entire design is based on CSS-grid, so it is fully responsive and fast
- Easy to override default components to add unique behavior and styles

The ultimate goal for this library was to create a framework that allowed for users to create their own calendar and components for use in the grid system. This allows for users to easily add additional functionality without bloating the base library with features not everyone may want.

The included default calendar components can be simply used as is, but the real power is being able to easily override these components. This allows consumers to use any state-management, styles, UX, or _whatever_ without needing them included in this library, and without interfering with it's overall behavior.

## 📚 Documentation

- Documentation can be found [**here**](https://bruceharrison1984.github.io/Schedulely-docs/)
- Storybook demo can be found [**here**](https://bruceharrison1984.github.io/Schedulely)

==> schedulely-0.0.31.tgz: package/README.md <==
# Schedulely

### Prerelease

_This component is still very early in development. Everything is currently still subject to massive change, so use at your own risk!_

![Large Calendar Preview](/assets/large_preview.png)

---

[![npm](https://img.shields.io/npm/v/schedulely)](https://www.npmjs.com/package/schedulely) [![npm bundle size](https://img.shields.io/bundlephobia/minzip/schedulely)](https://bundlephobia.com/package/schedulely) [![install size](https://packagephobia.com/badge?p=schedulely)](https://packagephobia.com/result?p=schedulely) ![NPM](https://img.shields.io/npm/l/schedulely?color=blue)

## 📃 Description

A react-based, light-weight, highly customizable Month calendar for React-based applications.

- Extremely small deployed package size (~150kb)
- Entire design is based on CSS-grid, so it is fully responsive and fast
- Easy to override default components to add unique behavior and styles

The ultimate goal for this library was to create a framework that allowed for users to create their own calendar and components for use in the grid system. This allows for users to easily add additional functionality without bloating the base library with features not everyone may want.

The included default calendar components can be simply used as is, but the real power is being able to easily override these components. This allows consumers to use any state-management, styles, UX, or _whatever_ without needing them included in this library, and without interfering with it's overall behavior.

## 📚 Documentation

- Documentation can be found [**here**](https://bruceharrison1984.github.io/Schedulely-docs/)
- Storybook demo can be found [**here**](https://bruceharrison1984.github.io/Schedulely)
